@@ -9,7 +9,7 @@
 #
 package Config::Model::Backend::OpenSsh::Ssh ;
 {
-  $Config::Model::Backend::OpenSsh::Ssh::VERSION = '1.223';
+  $Config::Model::Backend::OpenSsh::Ssh::VERSION = '1.226';
 }
 
 use Any::Moose ;
@@ -215,72 +215,16 @@ Config::Model::Backend::OpenSsh::Ssh - Backend for ssh configuration files
 
 =head1 SYNOPSIS
 
-=head2 invoke editor
-
-The following will launch a graphical editor (if L<Config::Model::TkUI>
-is installed):
-
- config-edit -application ssh
-
-=head2 command line
-
-This command will add a C<Host Foo> section in C<~/.ssh/config>: 
-
- config-edit -application ssh -ui none Host:Foo ForwardX11=yes
- 
-=head2 programmatic
-
-This code snippet will remove the C<Host Foo> section added above:
-
- use Config::Model ;
- use Log::Log4perl qw(:easy) ;
- my $model = Config::Model -> new ( ) ;
- my $inst = $model->instance (root_class_name => 'Ssh');
- $inst -> config_root ->load("Host~Foo") ;
- $inst->write_back() ;
+None
 
 =head1 DESCRIPTION
 
 This calls provides a backend to read and write ssh client configuration files.
 
-Once this module is installed, user root can edit C</etc/ssh/ssh_config> 
-with :
-
- # config-edit -application ssh 
-
-To edit F<~/.ssh/config>, run as a normal user:
-
- # config-edit -application ssh
-
-=head1 user interfaces
-
-As mentioned in L<config-edit>, several user interfaces are available:
-
-=over
-
-=item *
-
-A graphical interface is proposed by default if L<Config::Model::TkUI> is installed.
-
-=item *
-
-A Curses interface with option C<-ui curses> if L<Config::Model::CursesUI> is installed.
-
-=item *
-
-A Shell like interface with option C<-ui term>.
-
-=item *
-
-A L<Fuse> virtual file system with option C<< -ui fuse -fuse_dir <mountpoint> >> 
-if L<Fuse> is installed (Linux only)
-
-=back
-
 =head1 STOP
 
 The documentation provides on the reader and writer of OpenSsh configuration files.
-These details are not needed for the basic usages explained above.
+These details are not needed for the basic usages explained in L<Config::Model::OpenSsh>.
 
 =head1 Methods
 
@@ -305,4 +249,4 @@ Dominique Dumont, (ddumont at cpan dot org)
 
 =head1 SEE ALSO
 
-L<config-edit>, L<Config::Model>,
+L<cme>, L<Config::Model>, L<Config::Model::OpenSsh>
